summaryrefslogtreecommitdiffstats
path: root/src/kfeedback.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-06 14:15:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-06 14:15:01 -0600
commit1b89319fd93b88313cab40f1e9de24c067b04efb (patch)
tree80132996de993c3dcab4040864d7729842875b2d /src/kfeedback.h
parentd08a0ede1d2cb15bb14b0ff75eacf5c682b1fa0a (diff)
downloadkvpnc-1b89319fd93b88313cab40f1e9de24c067b04efb.tar.gz
kvpnc-1b89319fd93b88313cab40f1e9de24c067b04efb.zip
Initial TQt conversion
Diffstat (limited to 'src/kfeedback.h')
-rw-r--r--src/kfeedback.h93
1 files changed, 48 insertions, 45 deletions
diff --git a/src/kfeedback.h b/src/kfeedback.h
index 6ba6abd..34e077e 100644
--- a/src/kfeedback.h
+++ b/src/kfeedback.h
@@ -11,15 +11,15 @@
#ifndef KFeedback_h
#define KFeedback_h
-#include <qlistview.h>
-#include <qvbox.h>
+#include <tqlistview.h>
+#include <tqvbox.h>
#include <kdialogbase.h>
class KFeedbackForm;
class KFeedbackQuestionList;
class KFeedbackQuestion;
class KFeedbackAnswer;
-class QMultiLineEdit;
+class TQMultiLineEdit;
/**
@@ -29,14 +29,15 @@ class QMultiLineEdit;
class KFeedbackDialog: public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
**/
- KFeedbackDialog( const QString & feedbackMailAddress,
- const QString & helpTopic = QString::null );
+ KFeedbackDialog( const TQString & feedbackMailAddress,
+ const TQString & helpTopic = TQString() );
/**
@@ -82,16 +83,17 @@ protected:
* User is asked a list of questions, the answers of which will be sent via
* mail back to a feedback mail address.
**/
-class KFeedbackForm: public QVBox
+class KFeedbackForm: public TQVBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
**/
- KFeedbackForm( const QString & feedbackMailAddress,
- QWidget * parent );
+ KFeedbackForm( const TQString & feedbackMailAddress,
+ TQWidget * parent );
/**
* Destructor.
@@ -158,29 +160,30 @@ protected:
/**
* Format the "personal comments" field for sending mail.
**/
- QString formatComment();
+ TQString formatComment();
- QString _feedbackMailAddress;
+ TQString _feedbackMailAddress;
KFeedbackQuestionList * _questionList;
- QMultiLineEdit * _comment;
+ TQMultiLineEdit * _comment;
};
/**
* List of feedback questions presented in a @ref QListView widget.
**/
-class KFeedbackQuestionList: public QListView
+class KFeedbackQuestionList: public TQListView
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
**/
- KFeedbackQuestionList( QWidget *parent );
+ KFeedbackQuestionList( TQWidget *parent );
/**
* Destructor.
@@ -196,7 +199,7 @@ public:
/**
* The result of all answered questions in ASCII.
**/
- QString result();
+ TQString result();
/**
* Add a yes/no question to the list.
@@ -215,16 +218,16 @@ public:
* Returns a pointer to this question so you can add answers.
**/
- KFeedbackQuestion * addQuestion( const QString & text,
- const QString & id,
+ KFeedbackQuestion * addQuestion( const TQString & text,
+ const TQString & id,
bool exclusiveAnswer = true,
bool required = false );
/**
* Add a yes/no question to the list.
**/
- void addYesNoQuestion( const QString & text,
- const QString & id,
+ void addYesNoQuestion( const TQString & text,
+ const TQString & id,
bool required = false );
/**
@@ -232,7 +235,7 @@ public:
* Use @ref KFeedbackQuestion::next() to get the next one.
**/
KFeedbackQuestion * firstQuestion() const
- { return (KFeedbackQuestion *) QListView::firstChild(); }
+ { return (KFeedbackQuestion *) TQListView::firstChild(); }
/**
* Notify the list that another question has been answered.
@@ -259,7 +262,7 @@ signals:
/**
* A user feedback question to be inserted into a @ref KFeedbackQuestionList.
**/
-class KFeedbackQuestion: public QCheckListItem
+class KFeedbackQuestion: public TQCheckListItem
{
public:
@@ -285,8 +288,8 @@ public:
* checked at any one time, to 'false' if multiple answers are allowed.
**/
KFeedbackQuestion( KFeedbackQuestionList * parent,
- const QString & text,
- const QString & id,
+ const TQString & text,
+ const TQString & id,
bool exclusiveAnswer = true,
bool required = false,
bool open = true );
@@ -297,8 +300,8 @@ public:
* the mail. The answer IDs need only be unique for that question; answers
* to other questions may have the same ID.
**/
- void addAnswer( const QString & text,
- const QString & id );
+ void addAnswer( const TQString & text,
+ const TQString & id );
/**
* Returns if answering this question is required.
@@ -318,17 +321,17 @@ public:
* features_i_like="pink_elephant"
* features_i_like="studlycapslyfier"
**/
- QString result();
+ TQString result();
/**
* Return this question's ID.
**/
- QString id() { return _id; }
+ TQString id() { return _id; }
/**
* Return this question's text.
**/
- QString text();
+ TQString text();
/**
* Returns whether or not this question requires an exclusive answer.
@@ -339,22 +342,22 @@ public:
/**
* Returns the sort key.
*
* Reimplemented from @ref QListViewItem to maintain insertion order.
**/
- virtual QString key( int column, bool ascending ) const;
+ virtual TQString key( int column, bool ascending ) const;
/**
* Returns the next question or 0 if there is no more.
**/
KFeedbackQuestion * nextQuestion() const
- { return (KFeedbackQuestion *) QListViewItem::nextSibling(); }
+ { return (KFeedbackQuestion *) TQListViewItem::nextSibling(); }
/**
* Returns the first possible answer to this question.
* Use @ref KFeedbackAnswer::nextAnswer() to get the next one.
**/
KFeedbackAnswer * firstAnswer() const
- { return (KFeedbackAnswer *) QListViewItem::firstChild(); }
+ { return (KFeedbackAnswer *) TQListViewItem::firstChild(); }
/**
* Returns the @ref KFeedbackQuestionList this question belongs to or 0 if
@@ -365,14 +368,14 @@ public:
protected:
- QString _id;
+ TQString _id;
bool _exclusiveAnswer;
bool _required;
int _no;
};
-class KFeedbackAnswer: public QCheckListItem
+class KFeedbackAnswer: public TQCheckListItem
{
public:
/**
@@ -382,19 +385,19 @@ public:
* of many.
**/
KFeedbackAnswer( KFeedbackQuestion * parent,
- const QString & text,
- const QString & id,
+ const TQString & text,
+ const TQString & id,
bool exclusive = true );
/**
* Return this answer's ID.
**/
- QString id() { return _id; }
+ TQString id() { return _id; }
/**
* Return this answer's text.
**/
- QString text();
+ TQString text();
/**
* Returns whether or not this is an exclusive answer.
@@ -404,32 +407,32 @@ public:
/**
* Returns whether or not this answer is checked.
**/
- bool isChecked() { return QCheckListItem::isOn(); }
+ bool isChecked() { return TQCheckListItem::isOn(); }
/**
* Returns the next possible answer or 0 if there is no more.
**/
KFeedbackAnswer * nextAnswer() const
- { return (KFeedbackAnswer *) QListViewItem::nextSibling(); }
+ { return (KFeedbackAnswer *) TQListViewItem::nextSibling(); }
/**
* Returns the question to this answer.
**/
KFeedbackQuestion * question() const
- { return (KFeedbackQuestion *) QListViewItem::parent(); }
+ { return (KFeedbackQuestion *) TQListViewItem::parent(); }
/**
* Returns the sort key.
*
* Reimplemented from @ref QListViewItem to maintain insertion order.
**/
- virtual QString key( int column, bool ascending ) const;
+ virtual TQString key( int column, bool ascending ) const;
/**
* On/off change.
*
* Reimplemented from @ref QCheckListItem to monitor answering required
* questions. This method notifies the @ref KFeedbackQuestionList whenever
* a required question is being answered.
**/
@@ -437,7 +440,7 @@ public:
protected:
- QString _id;
+ TQString _id;
bool _exclusive;
int _no;
};
@@ -158,29 +160,30 @@ protected:
};
/**
- * List of feedback questions presented in a @ref QListView widget.
+ * List of feedback questions presented in a @ref TQListView widget.
**/
@@ -339,22 +342,22 @@ public:
* Returns the sort key.
*
- * Reimplemented from @ref QListViewItem to maintain insertion order.
+ * Reimplemented from @ref TQListViewItem to maintain insertion order.
**/
@@ -404,32 +407,32 @@ public:
* Returns the sort key.
*
- * Reimplemented from @ref QListViewItem to maintain insertion order.
+ * Reimplemented from @ref TQListViewItem to maintain insertion order.
**/
@@ -404,32 +407,32 @@ public:
* On/off change.
*
- * Reimplemented from @ref QCheckListItem to monitor answering required
+ * Reimplemented from @ref TQCheckListItem to monitor answering required
* questions. This method notifies the @ref KFeedbackQuestionList whenever
* a required question is being answered.